"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var log4js = require("log4js");
var sql = require('mssql');
var logger = log4js.getLogger('Sql');
var sqlConn;
function AccountMSSql(app) {
    sqlConn = app.get('sqlConn');
}
exports.AccountMSSql = AccountMSSql;
function CreateMainAccount(platformHash, accountId, user, token, countryCode, currencyCode, transcriptionRatePerHour, transcriptionRatePerSecond, semanticAnalysisRatePerSecond, cognitiveAnalysisRatePerSecond, createdByUserId) {
    return new sql.Request(sqlConn)
        .input('PlatformHash', sql.VarChar(100), platformHash)
        .input('AccountId', sql.VarChar(50), accountId)
        .input('User', sql.VarChar(50), user)
        .input('Token', sql.VarChar(50), token)
        .input('CountryCode', sql.VarChar(10), countryCode)
        .input('CurrencyCode', sql.VarChar(10), currencyCode)
        .input('TranscriptionRatePerHour', sql.Decimal(18, 5), transcriptionRatePerHour)
        .input('TranscriptionRatePerSecond', sql.Decimal(18, 5), transcriptionRatePerSecond)
        .input('SemanticAnalysisRatePerTransaction', sql.Decimal(18, 5), semanticAnalysisRatePerSecond)
        .input('CognitiveAnalysisRatePerTransaction', sql.Decimal(18, 5), cognitiveAnalysisRatePerSecond)
        .input('CreatedByUserId', sql.VarChar(50), createdByUserId)
        .execute('CreateMainAccount')
        .then(function (recordsets) {
        var recordset = (recordsets && recordsets.length > 0 ? recordsets[0] : null);
        var account = (recordset && recordset.length > 0 ? recordset[0] : null);
        return Promise.resolve(account);
    }).catch(function (err) {
        var errorMsg = (err && err.procName ? 'Error al ejecutar \'' + err.procName + '\': ' : 'Error al ejecutar consulta: ') + (err ? typeof err === 'string' ? err : err.message || err.description || '' : '');
        logger.error(errorMsg);
        return Promise.reject(err);
    });
}
exports.CreateMainAccount = CreateMainAccount;
function GetAllAccounts(search_criteria, search_expression) {
    return new sql.Request(sqlConn)
        .input('SearchCriteria', sql.VarChar(50), search_criteria)
        .input('SearchExpression', sql.VarChar(50), search_expression)
        .execute('GetAllAccounts')
        .then(function (recordsets) {
        var recordset = (recordsets && recordsets.length > 0 ? recordsets[0] : null);
        return Promise.resolve(recordset);
    }).catch(function (err) {
        var errorMsg = (err && err.procName ? 'Error al ejecutar \'' + err.procName + '\': ' : 'Error al ejecutar consulta: ') + (err ? typeof err === 'string' ? err : err.message || err.description || '' : '');
        logger.error(errorMsg);
        return Promise.reject(err);
    });
}
exports.GetAllAccounts = GetAllAccounts;
function GetAccounts(search_criteria, search_expression) {
    return new sql.Request(sqlConn)
        .input('SearchCriteria', sql.VarChar(50), search_criteria)
        .input('SearchExpression', sql.VarChar(50), search_expression)
        .execute('GetAccounts')
        .then(function (recordsets) {
        var recordset = (recordsets && recordsets.length > 0 ? recordsets[0] : null);
        return Promise.resolve(recordset);
    }).catch(function (err) {
        var errorMsg = (err && err.procName ? 'Error al ejecutar \'' + err.procName + '\': ' : 'Error al ejecutar consulta: ') + (err ? typeof err === 'string' ? err : err.message || err.description || '' : '');
        logger.error(errorMsg);
        return Promise.reject(err);
    });
}
exports.GetAccounts = GetAccounts;
function GetPlatformAccounts(installationId) {
    return new sql.Request(sqlConn)
        .input('InstallationId', sql.VarChar(100), installationId)
        .execute('GetPlatformAccounts')
        .then(function (recordsets) {
        var recordset = (recordsets && recordsets.length > 0 ? recordsets[0] : null);
        return Promise.resolve(recordset);
    }).catch(function (err) {
        var errorMsg = (err && err.procName ? 'Error al ejecutar \'' + err.procName + '\': ' : 'Error al ejecutar consulta: ') + (err ? typeof err === 'string' ? err : err.message || err.description || '' : '');
        logger.error(errorMsg);
        return Promise.reject(err);
    });
}
exports.GetPlatformAccounts = GetPlatformAccounts;
function GetRelatedAccounts(installationId) {
    return new sql.Request(sqlConn)
        .input('InstallationId', sql.VarChar(100), installationId)
        .execute('GetRelatedAccounts')
        .then(function (recordsets) {
        var recordset = (recordsets && recordsets.length > 0 ? recordsets[0] : null);
        return Promise.resolve(recordset);
    }).catch(function (err) {
        var errorMsg = (err && err.procName ? 'Error al ejecutar \'' + err.procName + '\': ' : 'Error al ejecutar consulta: ') + (err ? typeof err === 'string' ? err : err.message || err.description || '' : '');
        logger.error(errorMsg);
        return Promise.reject(err);
    });
}
exports.GetRelatedAccounts = GetRelatedAccounts;
function GetRelatedSubAccounts(installationId) {
    return new sql.Request(sqlConn)
        .input('InstallationId', sql.VarChar(100), installationId)
        .execute('GetRelatedSubAccounts')
        .then(function (recordsets) {
        var recordset = (recordsets && recordsets.length > 0 ? recordsets[0] : null);
        return Promise.resolve(recordset);
    }).catch(function (err) {
        var errorMsg = (err && err.procName ? 'Error al ejecutar \'' + err.procName + '\': ' : 'Error al ejecutar consulta: ') + (err ? typeof err === 'string' ? err : err.message || err.description || '' : '');
        logger.error(errorMsg);
        return Promise.reject(err);
    });
}
exports.GetRelatedSubAccounts = GetRelatedSubAccounts;
function GetAccount(platformHash, installationId, id) {
    return new sql.Request(sqlConn)
        .input('PlatformHash', sql.VarChar(100), platformHash)
        .input('Id', sql.VarChar(50), id)
        .input('InstallationId', sql.VarChar(50), installationId)
        .execute('GetAccount')
        .then(function (recordsets) {
        var recordset = (recordsets && recordsets.length > 0 ? recordsets[0] : null);
        var account = (recordset && recordset.length > 0 ? recordset[0] : null);
        return Promise.resolve(account);
    }).catch(function (err) {
        var errorMsg = (err && err.procName ? 'Error al ejecutar \'' + err.procName + '\': ' : 'Error al ejecutar consulta: ') + (err ? typeof err === 'string' ? err : err.message || err.description || '' : '');
        logger.error(errorMsg);
        return Promise.reject(err);
    });
}
exports.GetAccount = GetAccount;
function GetAccountStatusByVCC(installationId, vcc, active) {
    return new sql.Request(sqlConn)
        .input('InstallationId', sql.VarChar(50), installationId)
        .input('VCC', sql.VarChar(50), vcc)
        .input('Active', sql.Bit, active)
        .execute('GetAccountStatusByVcc')
        .then(function (recordsets) {
        var recordset = (recordsets && recordsets.length > 0 ? recordsets[0] : null);
        var account = (recordset && recordset.length > 0 ? recordset[0] : null);
        return Promise.resolve(account);
    }).catch(function (err) {
        var errorMsg = (err && err.procName ? 'Error al ejecutar \'' + err.procName + '\': ' : 'Error al ejecutar consulta: ') + (err ? typeof err === 'string' ? err : err.message || err.description || '' : '');
        logger.error(errorMsg);
        return Promise.reject(err);
    });
}
exports.GetAccountStatusByVCC = GetAccountStatusByVCC;
function GetAccountUser(installationId, accountId, subAccountId) {
    return new sql.Request(sqlConn)
        .input('InstallationId', sql.VarChar(100), installationId)
        .input('AccountId', sql.VarChar(50), accountId)
        .input('SubAccountId', sql.VarChar(50), subAccountId)
        .execute('GetAccountUser')
        .then(function (recordsets) {
        var recordset = (recordsets && recordsets.length > 0 ? recordsets[0] : null);
        var account = (recordset && recordset.length > 0 ? recordset[0] : null);
        return Promise.resolve(account);
    }).catch(function (err) {
        var errorMsg = (err && err.procName ? 'Error al ejecutar \'' + err.procName + '\': ' : 'Error al ejecutar consulta: ') + (err ? typeof err === 'string' ? err : err.message || err.description || '' : '');
        logger.error(errorMsg);
        return Promise.reject(err);
    });
}
exports.GetAccountUser = GetAccountUser;
function GetAccountByHashUserToken(platformHash, user, token) {
    return new sql.Request(sqlConn)
        .input('PlatformHash', sql.VarChar(100), platformHash)
        .input('User', sql.VarChar(50), user)
        .input('Token', sql.VarChar(50), token)
        .execute('GetAccountByHashUserToken')
        .then(function (recordsets) {
        var recordset = (recordsets && recordsets.length > 0 ? recordsets[0] : null);
        var account = (recordset && recordset.length > 0 ? recordset[0] : null);
        return Promise.resolve(account);
    }).catch(function (err) {
        var errorMsg = (err && err.procName ? 'Error al ejecutar \'' + err.procName + '\': ' : 'Error al ejecutar consulta: ') + (err ? typeof err === 'string' ? err : err.message || err.description || '' : '');
        logger.error(errorMsg);
        return Promise.reject(err);
    });
}
exports.GetAccountByHashUserToken = GetAccountByHashUserToken;
function GetAccountSubAccountExists(installationId, accountId, subAccountId) {
    return new sql.Request(sqlConn)
        .input('InstallationId', sql.VarChar(100), installationId)
        .input('AccountId', sql.VarChar(50), accountId)
        .input('SubAccountId', sql.VarChar(50), subAccountId)
        .execute('GetAccountSubAccountExists')
        .then(function (recordsets) {
        var recordset = (recordsets && recordsets.length > 0 ? recordsets[0] : null);
        var account = (recordset && recordset.length > 0 ? recordset[0] : null);
        return Promise.resolve(account);
    }).catch(function (err) {
        var errorMsg = (err && err.procName ? 'Error al ejecutar \'' + err.procName + '\': ' : 'Error al ejecutar consulta: ') + (err ? typeof err === 'string' ? err : err.message || err.description || '' : '');
        logger.error(errorMsg);
        return Promise.reject(err);
    });
}
exports.GetAccountSubAccountExists = GetAccountSubAccountExists;
function SaveAccount(platformHash, id, installationId, accountId, subAccountId, currencyCode, user, token, transcriptionRatePerHour, transcriptionRatePerSecond, semanticAnalysisRatePerTransaction, cognitiveAnalysisRatePerTransaction, createdByUserId, initialBalance) {
    return new sql.Request(sqlConn)
        .input('PlatformHash', sql.VarChar(100), platformHash)
        .input('Id', sql.VarChar(100), id)
        .input('InstallationId', sql.VarChar(100), installationId)
        .input('AccountId', sql.VarChar(50), accountId)
        .input('SubAccountId', sql.VarChar(50), subAccountId)
        .input('CurrencyCode', sql.VarChar(10), currencyCode)
        .input('User', sql.VarChar(50), user)
        .input('Token', sql.VarChar(50), token)
        .input('Balance', sql.Decimal(18, 5), initialBalance)
        .input('TranscriptionRatePerHour', sql.Decimal(18, 5), transcriptionRatePerHour)
        .input('TranscriptionRatePerSecond', sql.Decimal(18, 5), transcriptionRatePerSecond)
        .input('SemanticAnalysisRatePerTransaction', sql.Decimal(18, 5), semanticAnalysisRatePerTransaction)
        .input('CognitiveAnalysisRatePerTransaction', sql.Decimal(18, 5), cognitiveAnalysisRatePerTransaction)
        .input('CreatedByUserId', sql.VarChar(50), createdByUserId)
        .execute('SaveAccount')
        .then(function (recordsets) {
        var recordset = (recordsets && recordsets.length > 0 ? recordsets[0] : null);
        var output = (recordset && recordset.length > 0 ? recordset[0] : null);
        return Promise.resolve(output && output.result === 1);
    }).catch(function (err) {
        var errorMsg = (err && err.procName ? 'Error al ejecutar \'' + err.procName + '\': ' : 'Error al ejecutar consulta: ') + (err ? typeof err === 'string' ? err : err.message || err.description || '' : '');
        logger.error(errorMsg);
        return Promise.reject(err);
    });
}
exports.SaveAccount = SaveAccount;
function SaveAccountCurrency(installationId, accountId, newCountryCode, newCurrencyCode, convertAccountRates, convertSubAccountsRates, newTranscriptionRatePerHour, newTranscriptionRatePerSecond, newSemanticAnalysisRatePerTransaction, newCognitiveAnalysisRatePerTransaction, changeValue, user) {
    return new sql.Request(sqlConn)
        .input('InstallationId', sql.VarChar(100), installationId)
        .input('AccountId', sql.VarChar(50), accountId)
        .input('NewCountrycode', sql.VarChar(5), newCountryCode)
        .input('NewCurrencycode', sql.VarChar(5), newCurrencyCode)
        .input('ConvertAccountRates', sql.Bit(), convertAccountRates)
        .input('ConvertSubAccountsRates', sql.Bit(), convertSubAccountsRates)
        .input('NewTranscriptionRatePerHour', sql.Decimal(18, 5), newTranscriptionRatePerHour)
        .input('NewTranscriptionRatePerSecond', sql.Decimal(18, 5), newTranscriptionRatePerSecond)
        .input('NewSemanticAnalysisRatePerTransaction', sql.Decimal(18, 5), newSemanticAnalysisRatePerTransaction)
        .input('NewCognitiveAnalysisRatePerTransaction', sql.Decimal(18, 5), newCognitiveAnalysisRatePerTransaction)
        .input('ChangeValue', sql.Decimal(18, 5), changeValue)
        .input('UserId', sql.VarChar(50), user)
        .execute('SaveAccountCurrency')
        .then(function (recordsets) {
        var recordset = (recordsets && recordsets.length > 0 ? recordsets[0] : null);
        var output = (recordset && recordset.length > 0 ? recordset[0] : null);
        return Promise.resolve(output && output.result === 1);
    })
        .catch(function (err) {
        var errorMsg = (err && err.procName ? 'Error al ejecutar \'' + err.procName + '\': ' : 'Error al ejecutar consulta: ') + (err ? typeof err === 'string' ? err : err.message || err.description || '' : '');
        logger.error(errorMsg);
        return Promise.reject(err);
    });
}
exports.SaveAccountCurrency = SaveAccountCurrency;
function AccountSubAccountActivate(installationId, accountId, subAccountId, lastModifiedByUserId) {
    return new sql.Request(sqlConn)
        .input('InstallationId', sql.VarChar(100), installationId)
        .input('AccountId', sql.VarChar(50), accountId)
        .input('SubAccountId', sql.VarChar(50), subAccountId)
        .input('LastModifiedByUserId', sql.VarChar(50), lastModifiedByUserId)
        .execute('AccountSubAccountActivate')
        .then(function (recordsets) {
        var recordset = (recordsets && recordsets.length > 0 ? recordsets[0] : null);
        var output = (recordset && recordset.length > 0 ? recordset[0] : null);
        return Promise.resolve(output && output.result === 1);
    })
        .catch(function (err) {
        var errorMsg = (err && err.procName ? 'Error al ejecutar \'' + err.procName + '\': ' : 'Error al ejecutar consulta: ') + (err ? typeof err === 'string' ? err : err.message || err.description || '' : '');
        logger.error(errorMsg);
        return Promise.reject(err);
    });
}
exports.AccountSubAccountActivate = AccountSubAccountActivate;
function AccountSubAccountDeactivate(installationId, accountId, subAccountId, lastModifiedByUserId) {
    return new sql.Request(sqlConn)
        .input('InstallationId', sql.VarChar(100), installationId)
        .input('AccountId', sql.VarChar(50), accountId)
        .input('SubAccountId', sql.VarChar(50), subAccountId)
        .input('LastModifiedByUserId', sql.VarChar(50), lastModifiedByUserId)
        .execute('AccountSubAccountDeactivate')
        .then(function (recordsets) {
        var recordset = (recordsets && recordsets.length > 0 ? recordsets[0] : null);
        var output = (recordset && recordset.length > 0 ? recordset[0] : null);
        return Promise.resolve(output && output.result === 1);
    })
        .catch(function (err) {
        var errorMsg = (err && err.procName ? 'Error al ejecutar \'' + err.procName + '\': ' : 'Error al ejecutar consulta: ') + (err ? typeof err === 'string' ? err : err.message || err.description || '' : '');
        logger.error(errorMsg);
        return Promise.reject(err);
    });
}
exports.AccountSubAccountDeactivate = AccountSubAccountDeactivate;
function RechargeAccountSubAccountVCC(platformHash, installationId, accountId, subAccountId, vcc, balance, target, user) {
    return new sql.Request(sqlConn)
        .input('PlatformHash', sql.VarChar(100), platformHash)
        .input('InstallationId', sql.VarChar(100), installationId)
        .input('AccountId', sql.VarChar(50), accountId)
        .input('SubAccountId', sql.VarChar(50), subAccountId)
        .input('VCC', sql.VarChar(50), vcc)
        .input('User', sql.VarChar(50), user)
        .input('Balance', sql.Decimal(18, 5), balance)
        .input('Target', sql.VarChar(50), target)
        .input('User', sql.VarChar(50), user)
        .execute('AccountSubAccountVCCBalanceRecharge')
        .then(function (recordsets) {
        var recordset = (recordsets && recordsets.length > 0 ? recordsets[0] : null);
        var output = (recordset && recordset.length > 0 ? recordset[0] : null);
        return Promise.resolve(output && output.result === 1);
    }).catch(function (err) {
        var errorMsg = (err && err.procName ? 'Error al ejecutar \'' + err.procName + '\': ' : 'Error al ejecutar consulta: ') + (err ? typeof err === 'string' ? err : err.message || err.description || '' : '');
        logger.error(errorMsg);
        return Promise.reject(err);
    });
}
exports.RechargeAccountSubAccountVCC = RechargeAccountSubAccountVCC;
function GetMovements(installationId, startDate, endDate, accountId, subAccountId, vcc, currencies) {
    return new sql.Request(sqlConn)
        .input('InstallationId', sql.VarChar(100), installationId)
        .input('StartDate', sql.DateTime, startDate)
        .input('EndDate', sql.DateTime, endDate)
        .input('AccountId', sql.VarChar(50), accountId)
        .input('SubAccountId', sql.VarChar(50), subAccountId)
        .input('VCC', sql.VarChar(50), vcc)
        .input('Currencies', sql.VarChar(250), currencies)
        .execute('GetMovements')
        .then(function (recordsets) {
        var recordset = (recordsets && recordsets.length > 0 ? recordsets[0] : null);
        return Promise.resolve(recordset);
    }).catch(function (err) {
        var errorMsg = (err && err.procName ? 'Error al ejecutar \'' + err.procName + '\': ' : 'Error al ejecutar consulta: ') + (err ? typeof err === 'string' ? err : err.message || err.description || '' : '');
        logger.error(errorMsg);
        return Promise.reject(err);
    });
}
exports.GetMovements = GetMovements;
function GetMovementCurrencies(installationId, startDate, endDate, accountId, subAccountId, vcc) {
    return new sql.Request(sqlConn)
        .input('InstallationId', sql.VarChar(100), installationId)
        .input('StartDate', sql.DateTime, startDate)
        .input('EndDate', sql.DateTime, endDate)
        .input('AccountId', sql.VarChar(50), accountId)
        .input('SubAccountId', sql.VarChar(50), subAccountId)
        .input('VCC', sql.VarChar(50), vcc)
        .execute('GetMovementCurrencies')
        .then(function (recordsets) {
        var recordset = (recordsets && recordsets.length > 0 ? recordsets[0] : null);
        return Promise.resolve(recordset);
    })
        .catch(function (err) {
        var errorMsg = (err && err.procName ? 'Error al ejecutar \'' + err.procName + '\': ' : 'Error al ejecutar consulta: ') + (err ? typeof err === 'string' ? err : err.message || err.description || '' : '');
        logger.error(errorMsg);
        return Promise.reject(err);
    });
}
exports.GetMovementCurrencies = GetMovementCurrencies;
function GetCosts(installationId, startDate, endDate, accountId, subAccountId, vcc) {
    return new sql.Request(sqlConn)
        .input('InstallationId', sql.VarChar(100), installationId)
        .input('AccountId', sql.VarChar(50), accountId)
        .input('SubAccountId', sql.VarChar(50), subAccountId)
        .input('VCC', sql.VarChar(50), vcc)
        .execute('GetCosts')
        .then(function (recordsets) {
        var recordset = (recordsets && recordsets.length > 0 ? recordsets[0] : null);
        return Promise.resolve(recordset);
    }).catch(function (err) {
        var errorMsg = (err && err.procName ? 'Error al ejecutar \'' + err.procName + '\': ' : 'Error al ejecutar consulta: ') + (err ? typeof err === 'string' ? err : err.message || err.description || '' : '');
        logger.error(errorMsg);
        return Promise.reject(err);
    });
}
exports.GetCosts = GetCosts;
