"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var log4js = require("log4js");
var redis_config_1 = require("../../config/redis.config");
var logger = log4js.getLogger('Redis');
var redisClient;
function UserRedis(app) {
    redisClient = app.get('redisClient');
}
exports.UserRedis = UserRedis;
function SaveUser(user) {
    if (!user || !user.id)
        throw 'Se intento guardar un registro en una clave nula';
    return redisClient.hsetAsync(user.id, user.id, JSON.stringify(user))
        .then(function (result) {
        return redisClient.expireAsync('User', redis_config_1.REDIS_DATA_PERSISTENCE);
    }).then(function (result) {
        return Promise.resolve(true);
    }).catch(function (err) {
        var errorMsg = 'Error al ejecutar consulta: ' + (err ? typeof err === 'string' ? err : err.message || err.description || '' : '');
        logger.error(errorMsg);
        return Promise.reject(err);
    });
}
exports.SaveUser = SaveUser;
function DeleteUser(user) {
    if (!user || !user.id)
        throw 'Se intento eliminar un registro en una clave nula';
    return redisClient.hdelAsync('User', user.id)
        .then(function (result) {
        return Promise.resolve(true);
    }).catch(function (err) {
        var errorMsg = 'Error al ejecutar consulta: ' + (err ? typeof err === 'string' ? err : err.message || err.description || '' : '');
        logger.error(errorMsg);
        return Promise.reject(err);
    });
}
exports.DeleteUser = DeleteUser;
function DeleteUserById(userId) {
    if (!userId)
        throw 'Se intento eliminar un registro en una clave nula';
    return redisClient.hdelAsync('User', userId)
        .then(function (result) {
        return Promise.resolve(true);
    }).catch(function (err) {
        var errorMsg = 'Error al ejecutar consulta: ' + (err ? typeof err === 'string' ? err : err.message || err.description || '' : '');
        logger.error(errorMsg);
        return Promise.reject(err);
    });
}
exports.DeleteUserById = DeleteUserById;
function GetUser(userId) {
    if (!userId)
        throw 'Se intento consultar un registro en una clave nula(UserRedis)';
    return redisClient.hgetAsync('User', userId)
        .then(function (result) {
        var user;
        try {
            user = JSON.parse(result);
        }
        catch (err) {
            return Promise.resolve(null);
        }
        return Promise.resolve(user);
    }).catch(function (err) {
        var errorMsg = 'Error al ejecutar consulta: ' + (err ? typeof err === 'string' ? err : err.message || err.description || '' : '');
        logger.error(errorMsg);
        return Promise.reject(err);
    });
}
exports.GetUser = GetUser;
