"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var log4js = require("log4js");
var redis_config_1 = require("../../config/redis.config");
var logger = log4js.getLogger('Redis');
var redisClient;
function VccRedis(app) {
    redisClient = app.get('redisClient');
}
exports.VccRedis = VccRedis;
function SaveVCC(vcc, objVCC) {
    if (!objVCC || !objVCC.id)
        throw 'Se intento guardar un registro en una clave nula';
    return redisClient.hsetAsync(vcc + ':VCC', objVCC.id, JSON.stringify(objVCC))
        .then(function (result) {
        return redisClient.expireAsync(vcc + ':VCC', redis_config_1.REDIS_DATA_PERSISTENCE);
    }).then(function (result) {
        return Promise.resolve(true);
    }).catch(function (err) {
        var errorMsg = 'Error al ejecutar consulta: ' + (err ? typeof err === 'string' ? err : err.message || err.description || '' : '');
        logger.error(errorMsg);
        return Promise.reject(err);
    });
}
exports.SaveVCC = SaveVCC;
function GetVCC(vcc, vccId) {
    if (!vccId)
        throw 'Se intento consultar un registro en una clave nula vcc(VccRedis)';
    return redisClient.hgetAsync(vcc + ':VCC', vccId)
        .then(function (result) {
        var vcc;
        try {
            vcc = JSON.parse(result);
        }
        catch (err) {
            return Promise.resolve(null);
        }
        return Promise.resolve(vcc);
    }).catch(function (err) {
        var errorMsg = 'Error al ejecutar consulta: ' + (err ? typeof err === 'string' ? err : err.message || err.description || '' : '');
        logger.error(errorMsg);
        return Promise.reject(err);
    });
}
exports.GetVCC = GetVCC;
function SaveRequestData(vcc, objRequestData) {
    if (!objRequestData) {
        logger.warn('[VccRedis::SaveRequestData] Received RequestData is null');
        throw 'Se intento guardar un registro en una clave null';
    }
    logger.info('[VccRedis::SaveRequestData] Registering RequestData on redis');
    return redisClient.hsetAsync(vcc + ':RequestData', vcc, JSON.stringify(objRequestData))
        .then(function (result) {
        logger.info('[VccRedis::SaveRequestData] Setting the expire time');
        return redisClient.expireAsync(vcc + ':RequestData', redis_config_1.REDIS_DATA_PERSISTENCE);
    }).then(function (result) {
        return Promise.resolve(true);
    }).catch(function (err) {
        var errorMsg = 'Error on: ' + (err ? typeof err === 'string' ? err : err.message || err.description || '' : '');
        logger.error('[VccRedis::SaveRequestData] ' + errorMsg);
        return Promise.reject(err);
    });
}
exports.SaveRequestData = SaveRequestData;
function GetRequestData(vcc) {
    if (!vcc) {
        logger.warn('[VccRedis::GetRequestData] Received Vcc is null');
        throw 'Se intento consultar un registro en una clave nula vcc(RequesDataRedis)';
    }
    logger.info('[VccRedis::GetRequestData] Registering RequestData to redis');
    return redisClient.hgetAsync(vcc + ':RequestData', vcc)
        .then(function (result) {
        var requestData;
        try {
            logger.info('[VccRedis::GetRequestData] Parsing received object from redis');
            requestData = JSON.parse(result);
        }
        catch (err) {
            logger.info('[VccRedis::GetRequestData] Cann\'t parse object from redis');
            return Promise.resolve(null);
        }
        return Promise.resolve(requestData);
    }).catch(function (err) {
        var errorMsg = 'Requesting error: ' + (err ? typeof err === 'string' ? err : err.message || err.description || '' : '');
        logger.error('[VccRedis::GetRequestData] ' + errorMsg);
        return Promise.reject(err);
    });
}
exports.GetRequestData = GetRequestData;
