"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var moment = require("moment");
var log4js = require("log4js");
var mssql_service_1 = require("../db/mssql.service");
var promises_shared_1 = require("../shared/promises.shared");
var logger = log4js.getLogger('ServerScripts');
function ApiUserService(app) {
    app.post('/api/api_user/get_api_users/', function (req, res, next) {
        logger.info('[ApiUserService::get_api_users] Se recibio ' + req.method + ' para \'' + req.path + '\'');
        var vcc = req.body.vcc || '';
        promises_shared_1.DummyPromise()
            .then(function (result) {
            return mssql_service_1.MSSql.GetApiUsers(vcc);
        }).then(function (users) {
            if (res.headersSent)
                return;
            res.json({ status: true, description: 'OK', data: users });
        }).catch(function (err) {
            var clientMsg = (typeof err === 'string' ? err : 'CANNOT_PROCESS_REQUEST');
            var errorMsg = (typeof err === 'string' ? err : err.message || err.description || 'Error al ejecutar solicitud');
            logger.error('[ApiUserService::get_api_users] Error al procesar \'' + req.path + '\': ' + errorMsg);
            if (res.headersSent)
                return;
            res.json({ status: false, description: clientMsg, error: errorMsg });
        });
    });
    app.post('/api/api_user/get_api_user/:user?', function (req, res, next) {
        logger.info('[ApiUserService::get_api_user] Se recibio ' + req.method + ' para \'' + req.path + '\'');
        var vcc = req.params.vcc || '';
        var user = req.params.user || '';
        promises_shared_1.DummyPromise()
            .then(function (result) {
            return mssql_service_1.MSSql.GetApiUser(vcc, user);
        }).then(function (user) {
            if (res.headersSent)
                return;
            res.json({ status: true, description: 'OK', data: user });
        }).catch(function (err) {
            var clientMsg = (typeof err === 'string' ? err : 'CANNOT_PROCESS_REQUEST');
            var errorMsg = (typeof err === 'string' ? err : err.message || err.description || 'Error al ejecutar solicitud');
            logger.error('[ApiUserService::get_api_user] Error al procesar \'' + req.path + '\': ' + errorMsg);
            if (res.headersSent)
                return;
            res.json({ status: false, description: clientMsg, error: errorMsg });
        });
    });
    app.post('/api/api_user/create_api_user', function (req, res, next) {
        logger.info('[ApiUserService::create_api_user] Se recibio ' + req.method + ' para \'' + req.path + '\'');
        var nowUtc = moment().utc().toDate();
        var apiUser = {};
        apiUser.installationId = req.body.installationId;
        apiUser.vcc = req.body.vcc;
        apiUser.userApi = req.body.userApi;
        apiUser.pin = req.body.pin;
        apiUser.isLocked = false;
        apiUser.failedTry = 0;
        apiUser.createdDate = nowUtc;
        apiUser.createdByUserId = req.body.userSpeech;
        apiUser.createdByRemoteUser = true;
        promises_shared_1.DummyPromise()
            .then(function (result) {
            if (apiUser.vcc && apiUser.userApi && apiUser.pin) {
                return mssql_service_1.MSSql.SaveApiUser(apiUser);
            }
            else {
                throw 'ERROR_MISSING_PARAMETERS';
            }
        })
            .then(function (resultSaveUser) {
            if (res.headersSent)
                return;
            res.json({ status: resultSaveUser, description: (resultSaveUser ? 'OK' : resultSaveUser), data: resultSaveUser });
        }).catch(function (err) {
            var clientMsg = (typeof err === 'string' ? err : 'CANNOT_PROCESS_REQUEST');
            var errorMsg = (typeof err === 'string' ? err : err.message || err.description || 'Error al ejecutar solicitud');
            logger.error('[ApiUserService::create_api_user] Error al procesar \'' + req.path + '\': ' + errorMsg);
            if (res.headersSent)
                return;
            res.json({ status: false, description: clientMsg, error: errorMsg });
        });
    });
    app.post('/api/api_user/save_api_user', function (req, res, next) {
        logger.info('[ApiUserService::save_api_user] Se recibio ' + req.method + ' para \'' + req.path + '\'');
        var nowUtc = moment().utc().toDate();
        var apiUser = {};
        apiUser.installationId = req.body.installationId;
        apiUser.vcc = req.body.vcc;
        apiUser.userApi = req.body.userApi;
        apiUser.pin = req.body.pin;
        apiUser.lastModifiedDate = nowUtc;
        apiUser.lastModifiedByUserId = req.body.userSpeech;
        apiUser.lastModifiedByRemoteUser = true;
        promises_shared_1.DummyPromise()
            .then(function (result) {
            if (apiUser.vcc && apiUser.userApi && apiUser.pin) {
                return mssql_service_1.MSSql.SaveApiUser(apiUser);
            }
            else {
                throw 'ERROR_MISSING_PARAMETERS';
            }
        })
            .then(function (resultSaveUser) {
            if (res.headersSent)
                return;
            res.json({ status: resultSaveUser, description: (resultSaveUser ? 'OK' : resultSaveUser), data: resultSaveUser });
        }).catch(function (err) {
            var clientMsg = (typeof err === 'string' ? err : 'CANNOT_PROCESS_REQUEST');
            var errorMsg = (typeof err === 'string' ? err : err.message || err.description || 'Error al ejecutar solicitud');
            logger.error('[ApiUserService::save_api_user] Error al procesar \'' + req.path + '\': ' + errorMsg);
            if (res.headersSent)
                return;
            res.json({ status: false, description: clientMsg, error: errorMsg });
        });
    });
    app.post('/api/api_user/delete_api_user', function (req, res, next) {
        logger.info('[ApiUserService::delete_api_user] Se recibio ' + req.method + ' para \'' + req.path + '\'');
        var userId = req.body.user;
        var vcc = req.body.vcc;
        promises_shared_1.DummyPromise()
            .then(function (result) {
            if (!userId)
                throw 'Missing user input parameter';
            return DeleteUser(vcc, userId);
        })
            .then(function (resultDeleteUser) {
            if (!resultDeleteUser)
                throw 'FAILED_DELETE_API_USER';
            if (res.headersSent)
                return;
            res.json({ status: true, description: '', data: resultDeleteUser });
        }).catch(function (err) {
            var clientMsg = (typeof err === 'string' ? err : 'CANNOT_PROCESS_REQUEST');
            var errorMsg = (typeof err === 'string' ? err : err.message || err.description || 'Error al ejecutar solicitud');
            logger.error('[ApiUserService::delete_api_user] Error al procesar \'' + req.path + '\': ' + errorMsg);
            if (res.headersSent)
                return;
            res.json({ status: false, description: clientMsg, error: errorMsg });
        });
    });
    app.post('/api/api_user/delete_api_users', function (req, res, next) {
        logger.info('[ApiUserService::delete_api_users] Se recibio ' + req.method + ' para \'' + req.path + '\'');
        var vcc = req.body.vcc;
        var users = req.body.users || [];
        promises_shared_1.DummyPromise()
            .then(function (result) {
            if (!users)
                throw 'MISSING_USERS_INPUT_PARAMETER';
            var promiseArray = [];
            users.forEach(function (user) {
                promiseArray.push(DeleteUser(vcc, user));
            });
            return Promise.all(promiseArray);
        }).then(function (resultDeleteUsers) {
            if (res.headersSent)
                return;
            res.json({ status: true, description: '', data: resultDeleteUsers });
        }).catch(function (err) {
            var clientMsg = (typeof err === 'string' ? err : 'CANNOT_PROCESS_REQUEST');
            var errorMsg = (typeof err === 'string' ? err : err.message || err.description || 'Error al ejecutar solicitud');
            logger.error('[ApiUserService::delete_api_users] Error al procesar \'' + req.path + '\': ' + errorMsg);
            if (res.headersSent)
                return;
            res.json({ status: false, description: clientMsg, error: errorMsg });
        });
    });
    app.post('/api/api_user/auth', function (req, res, next) {
        var platformHash = req.body.platformHash;
        var vcc = req.body.vcc;
        var apiUser = req.body.apiUser;
        var pin = req.body.pin;
        var user = req.body.user;
        logger.info('[ApiUserService::auth] Received ' + req.method + ' method on \'' + req.path + '\'');
        promises_shared_1.DummyPromise()
            .then(function (result) {
            if (platformHash && vcc && apiUser && pin && user) {
                return mssql_service_1.MSSql.GetPlatformByHash(platformHash);
            }
            else {
                logger.info('[ApiUserService::auth] Received params: ', platformHash, vcc, apiUser, pin, user);
                throw 'SERVER_ERROR_MISSING_SEARCH_PARAMETERS';
            }
        })
            .then(function (result) {
            if (result === null)
                throw 'SERVER_ERROR_PLATFORM_NOT_FOUND';
            else
                return mssql_service_1.MSSql.ValidateApiUser(result.installationId, vcc, apiUser, pin, user);
        })
            .then(function (result) {
            if (result === null)
                throw 'SERVER_ERROR_CREDENTIALS_ERROR';
            else {
                if (res.headersSent)
                    return;
                res.json({ status: true, description: 'OK', data: result });
            }
        })
            .catch(function (err) {
            var clientMsg = (typeof err === 'string' ? err : 'Login failed');
            var errorMsg = (typeof err === 'string' ? err : err.message || err.description || 'Error al ejecutar solicitud');
            logger.error('[ApiUserService::auth] Error validating for userApi ' + apiUser + ' : ' + errorMsg);
            if (res.headersSent)
                return;
            res.status(401).json({ status: false, description: clientMsg, error: errorMsg });
        });
    });
}
exports.ApiUserService = ApiUserService;
function DeleteUser(vcc, userId) {
    var user, reason = '';
    return promises_shared_1.DummyPromise()
        .then(function (result) {
        if (!userId) {
            reason = 'MISSING_USER_ID_PARAMETER';
            throw reason;
        }
        return mssql_service_1.MSSql.GetApiUser(vcc, userId);
    }).then(function (result) {
        user = result;
        if (!result) {
            reason = 'ERROR_API_USER_NOT_FOUND';
            throw reason;
        }
        return mssql_service_1.MSSql.DeleteApiUser(vcc, userId);
    }).then(function (result) {
        if (!result) {
            reason = 'ERROR_DELETING_API_USER';
            throw reason;
        }
        return Promise.resolve(result);
    }).catch(function (error) {
        return SetError(userId, error);
    });
}
function SetError(userId, reason) {
    var details = null;
    if ((userId && userId.length) && (reason && reason.length)) {
        details = {};
        details.error = {
            userId: userId,
            reason: reason
        };
    }
    return Promise.resolve(details);
}
