"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var log4js = require("log4js");
var wc = require('world-countries');
var mssql_service_1 = require("../db/mssql.service");
var promises_shared_1 = require("../shared/promises.shared");
var logger = log4js.getLogger('ServerScripts');
function CurrencyService(app) {
    app.get('/api/currency/get_currencies/:search_criteria/:search_expression?', function (req, res, next) {
        logger.info('[CurrencyService::get_currencies] Received ' + req.method + ' method on \'' + req.path + '\'');
        var vcc = res.locals.vcc;
        var search_criteria = req.params.search_criteria || '';
        var search_expression = req.params.search_expression || '';
        promises_shared_1.DummyPromise()
            .then(function (result) {
            return mssql_service_1.MSSql.GetCurrencies(search_criteria, search_expression);
        })
            .then(function (result) {
            if (res.headersSent)
                return;
            res.json({ status: true, description: 'OK', data: result });
        })
            .catch(function (err) {
            var clientMsg = (typeof err === 'string' ? err : 'CANNOT_PROCESS_REQUEST');
            var errorMsg = (typeof err === 'string' ? err : err.message || err.description || 'SERVER_ERROR_REQUESTING_ERROR');
            if (errorMsg.split(' ').length === 1)
                clientMsg = errorMsg;
            logger.error('[CurrencyService::get_currencies] Error on \'' + req.path + '\': ' + errorMsg);
            if (res.headersSent)
                return;
            res.json({ status: false, description: clientMsg, error: errorMsg });
        });
    });
}
exports.CurrencyService = CurrencyService;
