"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var moment = require("moment");
var log4js = require("log4js");
var mssql_service_1 = require("../db/mssql.service");
var promises_shared_1 = require("../shared/promises.shared");
var platform_model_1 = require("../models/platform.model");
var config_1 = require("../config/config");
var file_manager_1 = require("../shared/file-manager");
var logger = log4js.getLogger('ServerScripts');
function PlatformService(app) {
    app.get('/api/platform/get_platforms/:search_criteria/:search_expression?', function (req, res, next) {
        logger.info('[PlatformService::get_platforms] Received ' + req.method + ' method on \'' + req.path + '\'');
        var vcc = res.locals.vcc;
        var search_criteria = req.params.search_criteria || '';
        var search_expression = req.params.search_expression || '';
        promises_shared_1.DummyPromise()
            .then(function (result) {
            return mssql_service_1.MSSql.GetPlatforms(search_criteria, search_expression);
        }).then(function (result) {
            if (res.headersSent)
                return;
            res.json({ status: true, description: 'OK', data: result });
        }).catch(function (err) {
            var clientMsg = (typeof err === 'string' ? err : 'CANNOT_PROCESS_REQUEST');
            var errorMsg = (typeof err === 'string' ? err : err.message || err.description || 'SERVER_ERROR_REQUESTING_ERROR');
            logger.error('[PlatformService::get_platforms] Error on \'' + req.path + '\': ' + errorMsg);
            if (res.headersSent)
                return;
            res.json({ status: false, description: clientMsg, error: errorMsg });
        });
    });
    app.get('/api/platform/get_platform/:platform_hash?', function (req, res, next) {
        logger.info('[PlatformService::get_platform] Received ' + req.method + ' method on \'' + req.path + '\'');
        var vcc = res.locals.vcc;
        var platform_hash = req.params.platform_hash || '';
        promises_shared_1.DummyPromise()
            .then(function (result) {
            return mssql_service_1.MSSql.GetPlatform(platform_hash);
        }).then(function (results) {
            var platformDomain = { platform: null, account: null, product: {} };
            if (results && results.length) {
                if (results[0] && results[0].length && results[0][0]) {
                    platformDomain.platform = results[0][0];
                }
                if (results[1] && results[1].length && results[1][0]) {
                    platformDomain.account = results[1][0];
                }
                if (results[2] && results[2].length) {
                    var tempLicenseItems = [];
                    var product = null;
                    var speech_1 = 'speech';
                    var quality_1 = 'quality';
                    tempLicenseItems = results[2];
                    product = tempLicenseItems.find(function (x) {
                        return x.product === speech_1.toUpperCase();
                    });
                    if (product) {
                        platformDomain.product[speech_1] = product.totalLicense;
                    }
                    product = tempLicenseItems.find(function (x) {
                        return x.product === quality_1.toUpperCase();
                    });
                    if (product) {
                        platformDomain.product[quality_1] = product.totalLicense;
                    }
                    platformDomain.product['expirationDate'] = product.expirationDate;
                }
            }
            if (res.headersSent)
                return;
            res.json({ status: true, description: 'OK', data: platformDomain });
        }).catch(function (err) {
            var clientMsg = (typeof err === 'string' ? err : 'CANNOT_PROCESS_REQUEST');
            var errorMsg = (typeof err === 'string' ? err : err.message || err.description || 'SERVER_ERROR_REQUESTING_ERROR');
            logger.error('[PlatformService::get_platform] Error on \'' + req.path + '\': ' + errorMsg, 'platform_hash:', platform_hash);
            if (res.headersSent)
                return;
            res.json({ status: false, description: clientMsg, error: errorMsg });
        });
    });
    app.post('/api/platform/upload_license_file?', function (req, res, next) {
        logger.info('Se recibió ' + req.method + ' para \'' + req.path + '\'');
        var vcc = res.locals.vcc;
        var userId = res.locals.userId;
        var nowUtc = moment().utc().toDate();
        var uploadToFolder = req.params.upload_dest || '';
        var tempFolderName;
        var tempZipFileName;
        var tempUploadPath;
        var resultUpload = false;
        var platformHashContent = '';
        tempFolderName = (uploadToFolder ? uploadToFolder : (config_1.LICENSE_TEMP_PREFIX + '-' + vcc + '-' + userId).toLowerCase() + '-' + nowUtc.valueOf());
        tempZipFileName = tempFolderName + '.lic';
        tempUploadPath = (uploadToFolder ? uploadToFolder : config_1.LICENSE_TEMP_PATH);
        promises_shared_1.DummyPromise()
            .then(function (result) {
            logger.info('[PlatformService::/api/platform/upload_license_file/] Getting tempFolderName:', tempFolderName, 'with tempZipFileName:', tempZipFileName, 'with tempUploadPath:', tempUploadPath);
            return file_manager_1.ExistInFileSystem(tempUploadPath);
        }).then(function (result) {
            if (result === false) {
                return file_manager_1.CreateFolder(tempUploadPath);
            }
            else {
                return true;
            }
        }).then(function (result) {
            if (result) {
                return file_manager_1.UploadFileToServer(tempZipFileName, tempUploadPath, req, res, 'lic');
            }
            else {
                return false;
            }
        }).then(function (result) {
            resultUpload = result;
            logger.info('[PlatformService::/api/platform/upload_license_file/] Getting resultUpload:', resultUpload, 'after UploadFileToServer');
            if (!resultUpload)
                throw 'COULD_NOT_UPLOAD_FILE';
            var fileName = tempUploadPath + "/" + tempZipFileName;
            logger.info('[PlatformService::/api/platform/upload_license_file/] Getting fileName:', fileName);
            return file_manager_1.ReadFileContent(fileName, 'utf-8');
        }).then(function (result) {
            if (result && result.length > 0) {
                platformHashContent = result.replace(/^\uFEFF/, '');
                return true;
            }
            else {
                throw 'EMPTY_FILE';
            }
        }).then(function (result) {
            if (result === void 0) { result = false; }
            if (result) {
                var tempLicenseFile = tempUploadPath + "/" + tempZipFileName;
                logger.info('[PlatformService::/api/platform/upload_license_file/] Getting tempLicenseFile:', tempLicenseFile);
                return file_manager_1.DeleteFile(tempLicenseFile);
            }
            return false;
        }).then(function (result) {
            logger.info('[PlatformService::/api/platform/upload_license_file/] Getting result:', result, 'after DeleteFile');
            if (result) {
                return Promise.resolve(platformHashContent);
            }
            return Promise.resolve(null);
        }).then(function (result) {
            if (res.headersSent)
                return;
            res.json({ status: resultUpload, description: (resultUpload ? 'FILE_STORED_SUCCESSFULLY' : 'FILE_UPLOAD_FAILED'), data: { tempFolderName: tempFolderName, platformHash: result } });
        }).catch(function (err) {
            var processMsg = (typeof err === 'string' ? err : 'CANNOT_PROCESS_REQUEST');
            var errorMsg = (typeof err === 'string' ? err : err.message || err.description || 'Error al ejecutar solicitud');
            logger.error('[PlatformService::/api/platform/upload_license_file/] Getting errorMsg:', errorMsg);
            if (res.headersSent)
                return;
            res.json({ status: false, description: processMsg, error: errorMsg });
        });
    });
    app.post('/api/platform/create_platform', function (req, res, next) {
        var platform = req.body.platform || null;
        var account = req.body.account || null;
        var product = req.body.product || null;
        var myUser = '';
        logger.info('[PlatformService::create_platform] Received ' + req.method + ' method on \'' + req.path + '\'');
        if (0 < platform.transcriptionRatePerHour
            &&
                platform.transcriptionRatePerHour < 0.036)
            throw 'SERVER_ERROR_TRANSCRIPTION_RATE_PER_HOUR_MINIMUN_EXCEPTION';
        promises_shared_1.DummyPromise()
            .then(function (result) {
            if (platform && platform.platformHash && account && product) {
                return mssql_service_1.MSSql.GetPlatformByHash(platform.platformHash);
            }
            else {
                logger.info('[PlatformService::create_platform] Received params: ', platform, myUser, account, product);
                throw 'SERVER_ERROR_MISSING_SEARCH_PARAMETERS';
            }
        })
            .then(function (result) {
            if (result === null)
                return mssql_service_1.MSSql.SavePlatformHash(platform.platformHash, platform.type, platform.environmentId, myUser);
            else
                throw 'SERVER_ERROR_PLATFORMHASH_ALREADY_EXISTS';
        })
            .then(function (result) {
            if (result === null)
                throw 'SERVER_ERROR_PLATFORMHASH_SAVING_ERROR';
            else
                return mssql_service_1.MSSql.SavePlatformData(platform.platformHash, platform.name, platform.description, platform.countryCode, platform.clientName, platform.clientContactName, platform.clientContactEmail, platform.inconcertContactName, platform.commercialContactName, platform.technicalContactName, platform.transcriptionRatePerHour, (platform.transcriptionRatePerHour / 3600), platform.semanticAnalysisRatePerTransaction, platform.cognitiveAnalysisRatePerTransaction, myUser);
        })
            .then(function (result) {
            if (result === null)
                throw 'SERVER_ERROR_PLATFORMDATA_SAVING_ERROR';
            else if (result) {
                return mssql_service_1.MSSql.CreateMainAccount(platform.platformHash, account.name, account.user, account.password, account.countryCode, account.currencyCode, account.transcriptionRatePerHour, (platform.transcriptionRatePerHour / 3600), account.semanticAnalysisRatePerTransaction, account.cognitiveAnalysisRatePerTransaction, myUser);
            }
        })
            .then(function (result) {
            if (result === null)
                throw 'SERVER_ERROR_MAINACCOUNT_SAVING_ERROR';
            else
                (result);
            return mssql_service_1.MSSql.CreateMainAccountBalance(platform.platformHash, account.name, account.balance, myUser);
        })
            .then(function (result) {
            if (result === null)
                throw 'SERVER_ERROR_MAINACCOUNT_BALANCE_SAVING_ERROR';
            else
                (result);
            return mssql_service_1.MSSql.CreatePlatformLicense(platform.platformHash, product.quality, product.speech, product.expirationDate, myUser);
        })
            .then(function (result) {
            if (result === null)
                throw 'SERVER_ERROR_PLATFORM_LICENSES_SAVING_ERROR';
            if (res.headersSent)
                return;
            res.json({ status: true, description: 'OK', data: result });
        })
            .catch(function (err) {
            var clientMsg = (typeof err === 'string' ? err : 'CANNOT_PROCESS_REQUEST');
            var errorMsg = (typeof err === 'string' ? err : err.message || err.description || 'SERVER_ERROR_REQUESTING_ERROR');
            logger.error('[PlatformService::create_platform] Error on \'' + req.path + '\': ' + errorMsg);
            if (res.headersSent)
                return;
            res.json({ status: false, description: clientMsg, error: errorMsg });
        });
    });
    app.post('/api/platform/save_platform', function (req, res, next) {
        var platform = req.body.platform || null;
        var product = req.body.product;
        var platformHashNew = req.body.platformHashNew || null;
        var myUser = '';
        logger.info('[PlatformService::save_platform] Received ' + req.method + ' method on \'' + req.path + '\'');
        if (0 < platform.transcriptionRatePerHour
            &&
                platform.transcriptionRatePerHour < 0.036)
            throw 'SERVER_ERROR_TRANSCRIPTION_RATE_PER_HOUR_MINIMUN_EXCEPTION';
        promises_shared_1.DummyPromise()
            .then(function (result) {
            if (platformHashNew != '' && platformHashNew != null && platformHashNew) {
                return mssql_service_1.MSSql.UpdatePlatformHash(platform.platformHash, platformHashNew, myUser);
            }
            else {
                return Promise.resolve(true);
            }
        })
            .then(function (result) {
            if (!result)
                throw 'ERROR_UPDATED_PLATFORM_HASH';
            return mssql_service_1.MSSql.SavePlatform(platform.platformHash, platform.type, platform.environmentId);
        })
            .then(function (result) {
            if (!result)
                throw 'SERVER_ERROR_UPDATED_PLATFORM';
            return mssql_service_1.MSSql.SavePlatformLicense(platform.platformHash, product.quality, product.speech, product.expirationDate, myUser);
        }).then(function (result) {
            if (!result)
                throw 'ERROR_UPDATED_PRODUCTS_LICENSES';
            if (platform && platform.platformHash) {
                return mssql_service_1.MSSql.SavePlatformData(platform.platformHash, platform.name, platform.description, platform.countryCode, platform.clientName, platform.clientContactName, platform.clientContactEmail, platform.inconcertContactName, platform.commercialContactName, platform.technicalContactName, platform.transcriptionRatePerHour, (platform.transcriptionRatePerHour / 3600), platform.semanticAnalysisRatePerTransaction, platform.cognitiveAnalysisRatePerTransaction, myUser);
            }
            else {
                logger.info('[PlatformService::save_platform] Received params: ', platform);
                throw 'SERVER_ERROR_MISSING_SEARCH_PARAMETERS';
            }
        }).then(function (result) {
            if (result === null)
                throw 'SERVER_ERROR_PLATFORM_LICENSES_SAVING_ERROR';
            if (res.headersSent)
                return;
            res.json({ status: true, description: 'OK', data: result });
        }).catch(function (err) {
            var clientMsg = (typeof err === 'string' ? err : 'CANNOT_PROCESS_REQUEST');
            var errorMsg = (typeof err === 'string' ? err : err.message || err.description || 'SERVER_ERROR_REQUESTING_ERROR');
            logger.error('[PlatformService::save_platform] Error on \'' + req.path + '\': ' + errorMsg);
            if (res.headersSent)
                return;
            res.json({ status: false, description: clientMsg, error: errorMsg });
        });
    });
    app.post('/api/platform/save_version', function (req, res, next) {
        var platformHash = req.headers['platform-hash'] || null;
        var buildVersion = req.body.buildVersion || null;
        logger.info('[PlatformService::save_version] Received ' + req.method + ' method on \'' + req.path + '\' with platfomHash \'' + platformHash + '\'');
        var genericResult = {};
        promises_shared_1.DummyPromise()
            .then(function (result) {
            if (platformHash && buildVersion) {
                return mssql_service_1.MSSql.GetPlatformByHash(platformHash);
            }
            else {
                logger.info('[BatchService::search_batch_id] Received params: ', platformHash, buildVersion);
                throw 'SERVER_ERROR_MISSING_SEARCH_PARAMETERS';
            }
        })
            .then(function (result) {
            if (result === null)
                throw 'SERVER_ERROR_PLATFORM_NOT_FOUND';
            else {
                return mssql_service_1.MSSql.SavePlatformBuildVersion(platformHash, result.installationId, buildVersion);
            }
        })
            .then(function (result) {
            if (res.headersSent)
                return;
            if (result) {
                genericResult.status = true;
                genericResult.description = 'OK';
                genericResult.data = result;
            }
            else {
                genericResult.status = false;
                genericResult.description = 'SERVER_ERROR_REQUEST_ERROR';
            }
            res.json(genericResult);
        })
            .catch(function (err) {
            var clientMsg = (typeof err === 'string' ? err : 'CANNOT_PROCESS_REQUEST');
            var errorMsg = (typeof err === 'string' ? err : err.message || err.description || 'SERVER_ERROR_REQUESTING_ERROR');
            logger.error('[BatchService::save_version] Error on \'' + req.path + '\': ' + errorMsg);
            if (res.headersSent)
                return;
            genericResult.status = false;
            genericResult.description = clientMsg;
            genericResult.error = errorMsg;
            res.json(genericResult);
        });
    });
    app.post('/api/activation/get_platform_status', function (req, res, next) {
        var platformHash = req.body.platformHash || null;
        var installationId = req.body.installationId || null;
        var macAddress = req.body.macAddress || null;
        var publicIp = req.body.publicIp || null;
        var serviceData = [];
        logger.info('[PlatformService::get_platform_status] Received ' + req.method + ' method on \'' + req.path + '\'');
        logger.info('[PlatformService::get_platform_status] Received ' + req.body);
        promises_shared_1.DummyPromise()
            .then(function (result) {
            if (installationId && macAddress && publicIp)
                return mssql_service_1.MSSql.GetPlatformByData(installationId, macAddress, publicIp);
            else {
                logger.info('[PlatformService::get_platform_status] Received params: ', platformHash, installationId, macAddress, publicIp);
                throw 'SERVER_ERROR_MISSING_SEARCH_PARAMETERS';
            }
        })
            .then(function (result) {
            if (result === null)
                throw 'SERVER_ERROR_NOT_FOUND_PLATFORM_DATA';
            else {
                if (result.isActivated) {
                    if (res.headersSent)
                        return;
                    serviceData['platformStatus'] = result;
                    return mssql_service_1.MSSql.GetPlatformAccounts(installationId);
                }
                else
                    throw 'SERVER_ERROR_NOT_ACTIVATED_PLATFORM';
            }
        })
            .then(function (result) {
            if (result === null)
                throw 'SERVER_ERROR_NOT_FOUND_PLATFORM_ACCOUNTS';
            else {
                if (res.headersSent)
                    return;
                serviceData['platformAccounts'] = result;
                return mssql_service_1.MSSql.GetRelatedAccounts(installationId);
            }
        })
            .then(function (result) {
            if (result === null)
                throw 'SERVER_ERROR_NOT_FOUND_ACCOUNT';
            else {
                if (res.headersSent)
                    return;
                serviceData['accountList'] = result;
                return mssql_service_1.MSSql.GetRelatedSubAccounts(installationId);
            }
        })
            .then(function (result) {
            if (result === null)
                throw 'SERVER_ERROR_NOT_FOUND_SUBACCOUNT';
            else {
                if (res.headersSent)
                    return;
                serviceData['subAccountList'] = result;
                var resData = {
                    platformStatus: serviceData['platformStatus'],
                    platformAccounts: serviceData['platformAccounts'],
                    accountList: serviceData['accountList'],
                    subAccountList: serviceData['subAccountList'],
                };
                res.json({ status: true, description: 'OK', data: resData });
            }
        })
            .catch(function (err) {
            var clientMsg = (typeof err === 'string' ? err : 'CANNOT_PROCESS_REQUEST');
            var errorMsg = (typeof err === 'string' ? err : err.message || err.description || 'SERVER_ERROR_REQUESTING_ERROR');
            logger.error('[PlatformService::get_platform_status] Error on \'' + req.path + '\': ' + errorMsg);
            if (res.headersSent)
                return;
            res.json({ status: false, description: clientMsg, error: errorMsg });
        });
    });
    app.post('/api/activation/activate_platform', function (req, res, next) {
        var platformHash = req.body.platformHash || null;
        var user = req.body.user || null;
        var token = req.body.token || null;
        var installationId = req.body.data.installationId || null;
        var macAddress = req.body.data.macAddress || null;
        var publicIp = req.body.data.publicIp || null;
        logger.info('[PlatformService::activate_platform] Received ' + req.method + ' method on \'' + req.path + '\'');
        promises_shared_1.DummyPromise()
            .then(function (result) {
            if (platformHash && user && token && installationId && macAddress && publicIp) {
                return mssql_service_1.MSSql.GetPlatformByHash(platformHash);
            }
            else {
                logger.info('[PlatformService::activate_platform] Received params: ', platformHash, user, token, installationId, macAddress, publicIp);
                throw 'SERVER_ERROR_MISSING_SEARCH_PARAMETERS';
            }
        })
            .then(function (result) {
            if (result === null)
                throw 'SERVER_ERROR_NOT_FOUND_PLATFORM';
            else if (result) {
                if (result.isActivated)
                    throw 'SERVER_ERROR_PLATFORM_IS_ALREADY_ACTIVATED';
                else
                    return mssql_service_1.MSSql.GetAccountByHashUserToken(platformHash, user, token);
            }
        })
            .then(function (result) {
            if (result === null)
                throw 'SERVER_ERROR_CREDENTIALS_ERROR';
            else if (result) {
                if (result.level && result.level !== 1)
                    throw 'SERVER_ERROR_ACCOUNT_LEVEL_ERROR';
                else
                    return mssql_service_1.MSSql.ActivatePlatform(platformHash, installationId, macAddress, publicIp, user, token);
            }
        })
            .then(function (result) {
            if (result && result.isActivated === false)
                throw 'SERVER_SUCCESS_PLATFORM_ACTIVATION_FAILED';
            else {
                if (res.headersSent)
                    return;
                res.json({ status: true, description: (result ? 'SERVER_SUCCESS_PLATFORM_ACTIVATION_COMPLETED' : 'SERVER_ERROR_PLATFORM_ACTIVATION_FAILED'), data: result });
            }
        })
            .catch(function (err) {
            var clientMsg = (typeof err === 'string' ? err : 'CANNOT_PROCESS_REQUEST');
            var errorMsg = (typeof err === 'string' ? err : err.message || err.description || 'SEVER_ERROR_REQUESTING_ERROR');
            logger.error('[PlatformService::activate_platform] Error on \'' + req.path + '\': ' + errorMsg);
            if (res.headersSent)
                return;
            res.json({ status: false, description: clientMsg, error: errorMsg });
        });
    });
    app.post('/api/activation/get_platform_available_licenses', function (req, res, next) {
        var platformHash = req.body.platformHash || null;
        var platform = new platform_model_1.Platform;
        logger.info('[PlatformService::get_platform_available_licenses] Received ' + req.method + ' method on \'' + req.path + '\'');
        promises_shared_1.DummyPromise()
            .then(function (result) {
            if (platformHash) {
                return mssql_service_1.MSSql.GetPlatformByHash(platformHash);
            }
            else {
                logger.info('[PlatformService::get_platform_available_licenses] Received params: ', platformHash);
                throw 'SERVER_ERROR_MISSING_SEARCH_PARAMETERS';
            }
        })
            .then(function (result) {
            if (result === null)
                throw 'SERVER_ERROR_NOT_FOUND_PLATFORM';
            else if (result && result.status === 0)
                throw 'SERVER_ERROR_NOT_ACTIVATED_PLATFORM';
            else {
                if (res.headersSent)
                    return;
                platform = result;
                return mssql_service_1.MSSql.GetPlatformAvailableLicenses(platformHash, platform.installationId);
            }
        })
            .then(function (result) {
            if (result === null)
                throw 'SERVER_ERROR_NOT_FOUND_PLATFORM_AVAILABLE_LICENSES';
            else {
                if (res.headersSent)
                    return;
                res.json({ status: true, description: 'OK', data: result });
            }
        })
            .catch(function (err) {
            var clientMsg = (typeof err === 'string' ? err : 'CANNOT_PROCESS_REQUEST');
            var errorMsg = (typeof err === 'string' ? err : err.message || err.description || 'SERVER_ERROR_REQUESTING_ERROR');
            logger.error('[PlatformService::get_platform_available_licenses] Error on \'' + req.path + '\': ' + errorMsg);
            if (res.headersSent)
                return;
            res.json({ status: false, description: clientMsg, error: errorMsg });
        });
    });
    app.post('/api/platform/get_installation_ids/', function (req, res, next) {
        logger.info('[PlatformService::get_platforms] Received ' + req.method + ' method on \'' + req.path + '\'');
        var installationId = req.body.installationId ? req.body.installationId : null;
        promises_shared_1.DummyPromise()
            .then(function (result) {
            return mssql_service_1.MSSql.GetInstallationIds(installationId);
        }).then(function (result) {
            if (res.headersSent)
                return;
            res.json({ status: true, description: 'OK', data: result });
        }).catch(function (err) {
            var clientMsg = (typeof err === 'string' ? err : 'CANNOT_PROCESS_REQUEST');
            var errorMsg = (typeof err === 'string' ? err : err.message || err.description || 'SERVER_ERROR_REQUESTING_ERROR');
            logger.error('[PlatformService::get_platforms] Error on \'' + req.path + '\': ' + errorMsg);
            if (res.headersSent)
                return;
            res.json({ status: false, description: clientMsg, error: errorMsg });
        });
    });
}
exports.PlatformService = PlatformService;
