"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var log4js = require("log4js");
var mssql_service_1 = require("../db/mssql.service");
var promises_shared_1 = require("../shared/promises.shared");
var platform_model_1 = require("../models/platform.model");
var logger = log4js.getLogger('ServerScripts');
function VCCService(app) {
    app.post('/api/vcc/create_vcc', function (req, res, next) {
        var platformHash = req.body.platformHash || null;
        var accountId = req.body.account || null;
        var subAccountId = req.body.subAccount || null;
        var vcc = req.body.vcc || null;
        var products = req.body.products || [];
        var accountVcc = req.body.accountVcc || null;
        var platform = new platform_model_1.Platform;
        var myUser = res.locals.userId || null;
        logger.info('[VCCService::create_vcc] Received ' + req.method + ' method on \'' + req.path + '\'');
        if (0 < accountVcc.transcriptionRatePerHour
            &&
                accountVcc.transcriptionRatePerHour < 0.036)
            throw 'SERVER_ERROR_TRANSCRIPTION_RATE_PER_HOUR_MINIMUN_EXCEPTION';
        promises_shared_1.DummyPromise()
            .then(function (result) {
            if (platformHash && accountId && vcc && products && accountVcc) {
                return mssql_service_1.MSSql.GetPlatformByHash(platformHash);
            }
            else {
                logger.info('[VCCService::create_vcc] Received params: ', platformHash, accountId, subAccountId, vcc, JSON.stringify(products), JSON.stringify(accountVcc));
                throw 'SERVER_ERROR_MISSING_SEARCH_PARAMETERS';
            }
        })
            .then(function (result) {
            if (result === null)
                throw 'SERVER_ERROR_NOT_FOUND_PLATFORM';
            else if (result && result.status === 0)
                throw 'SERVER_ERROR_NOT_ACTIVATED_PLATFORM';
            else {
                if (res.headersSent)
                    return;
                platform = result;
                return mssql_service_1.MSSql.GetAccountSubAccountExists(platform.installationId, accountId, subAccountId);
            }
        })
            .then(function (result) {
            if (result === null)
                throw 'SERVER_ERROR_ACCOUNT_SUBACCOUNT_NOT_FOUND';
            else {
                if (res.headersSent)
                    return;
                return mssql_service_1.MSSql.GetAccountVccByAccountVcc(platform.installationId, accountId, vcc);
            }
        })
            .then(function (result) {
            if (result !== null)
                throw 'SERVER_ERROR_VCC_ALREADY_EXISTS';
            else {
                if (res.headersSent)
                    return;
                return mssql_service_1.MSSql.GetAccountVccByAccountSubAccountVcc(platform.installationId, accountId, subAccountId);
            }
        })
            .then(function (result) {
            if (result !== null)
                throw 'SERVER_ERROR_SUBACCOUNT_ALREADY_HAVE_ASSOCIATED_VCC';
            else {
                if (res.headersSent)
                    return;
                return mssql_service_1.MSSql.CreateAccountVCC(platformHash, platform.installationId, accountId, subAccountId, vcc, accountVcc.transcriptionRatePerHour, accountVcc.transcriptionRatePerSecond, accountVcc.semanticAnalysisRatePerTransaction, accountVcc.cognitiveAnalysisRatePerTransaction, accountVcc.asignableBalance, products.toString(), myUser);
            }
        })
            .then(function (result) {
            if (result === null)
                throw 'SERVER_ERROR_CREATE_VCC_FAILED';
            else {
                if (res.headersSent)
                    return;
                res.json({ status: result, description: 'OK', data: result });
            }
        })
            .catch(function (err) {
            var clientMsg = (typeof err === 'string' ? err : 'CANNOT_PROCESS_REQUEST');
            var errorMsg = (typeof err === 'string' ? err : err.message || err.description || 'SERVER_ERROR_REQUESTING_ERROR');
            if (errorMsg.split(' ').length === 1)
                clientMsg = errorMsg;
            logger.error('[VCCService::create_vcc] Error on \'' + req.path + '\': ' + errorMsg);
            if (res.headersSent)
                return;
            res.json({ status: false, description: clientMsg, error: errorMsg });
        });
    });
    app.post('/api/vcc/update_vcc', function (req, res, next) {
        var platformHash = req.headers['platform-hash'];
        var vcc = req.body.vcc || null;
        var products = req.body.products || [];
        var myUser = res.locals.userId || null;
        logger.info('[VCCService::update_vcc] Received ' + req.method + ' method on \'' + req.path + '\'');
        promises_shared_1.DummyPromise()
            .then(function (result) {
            if (platformHash && vcc) {
                return mssql_service_1.MSSql.SaveAccountVCCProduct(platformHash, vcc, products.toString(), myUser);
            }
            else {
                logger.info('[VCCService::update_vcc] Received params: ', platformHash, vcc);
                throw 'SERVER_ERROR_MISSING_SEARCH_PARAMETERS';
            }
        })
            .then(function (result) {
            if (result === null)
                throw 'SERVER_ERROR_UPDATE_VCC_FAILED';
            else {
                if (res.headersSent)
                    return;
                res.json({ status: result, description: 'OK', data: result });
            }
        })
            .catch(function (err) {
            var clientMsg = (typeof err === 'string' ? err : 'CANNOT_PROCESS_REQUEST');
            var errorMsg = (typeof err === 'string' ? err : err.message || err.description || 'SERVER_ERROR_REQUESTING_ERROR');
            logger.error('[VCCService::update_vcc] Error on \'' + req.path + '\': ' + errorMsg);
            if (res.headersSent)
                return;
            res.json({ status: false, description: clientMsg, error: errorMsg });
        });
    });
    app.post('/api/vcc/get_vcc_status', function (req, res, next) {
        var platformHash = req.body.platformHash || null;
        var installationId = req.body.installationId || null;
        var vcc = req.body.vcc || null;
        logger.info('[VCCService::get_vcc_status] Received ' + req.method + ' method on \'' + req.path + '\'');
        var platform = new platform_model_1.Platform;
        var resData = {
            vcc: null,
            products: null
        };
        promises_shared_1.DummyPromise()
            .then(function (result) {
            if (platformHash && vcc) {
                return mssql_service_1.MSSql.GetPlatformByHash(platformHash);
            }
            else {
                logger.info('[VCCService::get_vcc_status] Received params: ', platformHash, vcc);
                throw 'SERVER_ERROR_MISSING_SEARCH_PARAMETERS';
            }
        })
            .then(function (result) {
            if (result === null)
                throw 'SERVER_ERROR_NOT_FOUND_PLATFORM';
            else if (result && result.status === 0)
                throw 'SERVER_ERROR_NOT_ACTIVATED_PLATFORM';
            else {
                if (res.headersSent)
                    return;
                platform = result;
                return mssql_service_1.MSSql.GetAccountVCC(platform.installationId, vcc);
            }
        })
            .then(function (result) {
            if (result === null)
                throw 'SERVER_ERROR_NOT_FOUND_ACCOUNT_VCC';
            else {
                resData.vcc = result;
                return mssql_service_1.MSSql.GetAccountVccProducts(platform.installationId, vcc);
            }
        })
            .then(function (result) {
            if (result === null)
                throw 'SERVER_ERROR_NOT_FOUND_ACCOUNT_VCC_PRODUCTS';
            else {
                resData.products = result;
                if (res.headersSent)
                    return;
                res.json({ status: true, description: 'OK', data: resData });
            }
        })
            .catch(function (err) {
            var clientMsg = (typeof err === 'string' ? err : 'CANNOT_PROCESS_REQUEST');
            var errorMsg = (typeof err === 'string' ? err : err.message || err.description || 'SERVER_ERROR_REQUESTING_ERROR');
            logger.error('[PlatformService::get_vcc_status] Error on \'' + req.path + '\': ' + errorMsg);
            if (res.headersSent)
                return;
            res.json({ status: false, description: clientMsg, error: errorMsg });
        });
    });
    app.post('/api/vcc/get_vcc_rates', function (req, res, next) {
        var platformHash = req.body.platformHash || null;
        var installationId = req.body.installationId || null;
        var vcc = req.body.vcc || null;
        var processId = req.body.processId || null;
        logger.info('[VCCService::get_vcc_rates] Received ' + req.method + ' method on \'' + req.path + '\'');
        var platform = new platform_model_1.Platform;
        promises_shared_1.DummyPromise()
            .then(function (result) {
            if (platformHash && vcc) {
                return mssql_service_1.MSSql.GetPlatformByHash(platformHash);
            }
            else {
                logger.info('[VCCService::get_vcc_rates] Received params: ', platformHash, vcc);
                throw 'SERVER_ERROR_MISSING_SEARCH_PARAMETERS';
            }
        })
            .then(function (result) {
            if (result === null)
                throw 'SERVER_ERROR_NOT_FOUND_PLATFORM';
            else if (result && result.status === 0)
                throw 'SERVER_ERROR_NOT_ACTIVATED_PLATFORM';
            else {
                if (res.headersSent)
                    return;
                platform = result;
                return mssql_service_1.MSSql.GetAccountVccRates(platform.installationId, vcc, processId);
            }
        })
            .then(function (result) {
            if (result === null)
                throw 'SERVER_ERROR_NOT_FOUND_ACCOUNT_VCC';
            else {
                if (res.headersSent)
                    return;
                res.json({ status: true, description: 'OK', data: result });
            }
        })
            .catch(function (err) {
            var clientMsg = (typeof err === 'string' ? err : 'CANNOT_PROCESS_REQUEST');
            var errorMsg = (typeof err === 'string' ? err : err.message || err.description || 'SERVER_ERROR_REQUESTING_ERROR');
            logger.error('[PlatformService::get_vcc_rates] Error on \'' + req.path + '\': ' + errorMsg);
            if (res.headersSent)
                return;
            res.json({ status: false, description: clientMsg, error: errorMsg });
        });
    });
    app.post('/api/vcc/get_vcc_balance', function (req, res, next) {
        var platformHash = req.body.platformHash || null;
        var installationId = req.body.installationId || null;
        var vcc = req.body.vcc || null;
        var systemService = req.body.product || null;
        var platform = new platform_model_1.Platform;
        logger.info('[VCCService::get_vcc_balance] Received ' + req.method + ' method on \'' + req.path + '\'');
        promises_shared_1.DummyPromise()
            .then(function (result) {
            if (platformHash && vcc) {
                return mssql_service_1.MSSql.GetPlatformByHash(platformHash);
            }
            else {
                logger.info('[VCCService::get_vcc_balance] Received params: ', platformHash, installationId, vcc);
                throw 'SERVER_ERROR_MISSING_SEARCH_PARAMETERS';
            }
        })
            .then(function (result) {
            if (result === null)
                throw 'SERVER_ERROR_PLATFORM_NOT_FOUND';
            else if (res.headersSent)
                return;
            platform = result;
            return mssql_service_1.MSSql.GetAccountVCC(platform.installationId, vcc);
        })
            .then(function (result) {
            if (result === null)
                throw 'SERVER_ERROR_VCC_NOT_FOUND';
            else
                return mssql_service_1.MSSql.GetAccountSubAccountVCCBalance(platformHash, platform.installationId, result.accountId, result.subAccountId, vcc, systemService);
        })
            .then(function (result) {
            if (result === null)
                throw 'SERVER_ERROR_NOT_FOUND_VCC_BALANCE';
            else {
                if (res.headersSent)
                    return;
                res.json({ status: true, description: 'OK', data: result });
            }
        })
            .catch(function (err) {
            var clientMsg = (typeof err === 'string' ? err : 'CANNOT_PROCESS_REQUEST');
            var errorMsg = (typeof err === 'string' ? err : err.message || err.description || 'SERVER_ERROR_REQUESTING_ERROR');
            logger.error('[AccountService::get_account_balance] Error on \'' + req.path + '\': ' + errorMsg);
            if (res.headersSent)
                return;
            res.json({ status: false, description: clientMsg, error: errorMsg });
        });
    });
    app.post('/api/vcc/balance_allocation', function (req, res, next) {
        var platformHash = req.body.platformHash || null;
        var installationId = req.body.installationId || null;
        var accountId = req.body.account || null;
        var subAccountId = req.body.subAccount || null;
        var vcc = req.body.vcc || null;
        var data = req.body.data || null;
        var myUser = res.locals.userId || null;
        var allocationResult = [];
        logger.info('[VCCService::balance_allocation] Received ' + req.method + ' method on \'' + req.path + '\'');
        promises_shared_1.DummyPromise()
            .then(function (result) {
            if (platformHash && installationId && accountId && data) {
                return mssql_service_1.MSSql.GetPlatformByHash(platformHash);
            }
            else {
                logger.info('[VCCService::balance_allocation] Received params: ', platformHash, installationId, accountId, data);
                throw 'SERVER_ERROR_MISSING_SEARCH_PARAMETERS';
            }
        })
            .then(function (result) {
            if (result === null)
                throw 'SERVER_ERROR_PLATFORM_NOT_FOUND';
            else {
                return mssql_service_1.MSSql.GetAccountSubAccountVCCBalanceSummary(platformHash, installationId, accountId, subAccountId, vcc, null);
            }
        })
            .then(function (result) {
            if (result === null)
                throw 'SERVER_ERROR_NOT_VCC_BALANCE';
            var receivedTotal = 0;
            data.map(function (e) { return receivedTotal += e.total; });
            return mssql_service_1.MSSql.TransactionAccountSubAccountVCCBalanceAllocation(platformHash, installationId, accountId, subAccountId, vcc, data, myUser);
        })
            .then(function (result) {
            if (result === null)
                throw 'SERVER_ERROR_BALANCE_ALLOCATION_SAVE_FAILED';
            else {
                if (res.headersSent)
                    return;
                res.json({ status: true, description: 'OK', data: result });
            }
        })
            .catch(function (err) {
            var clientMsg = (typeof err === 'string' ? err : 'CANNOT_PROCESS_REQUEST');
            var errorMsg = (typeof err === 'string' ? err : err.message || err.description || 'SERVER_ERROR_REQUESTING_ERROR');
            logger.error('[VCCService::balance_allocation] Error on \'' + req.path + '\': ' + errorMsg);
            if (res.headersSent)
                return;
            res.json({ status: false, description: clientMsg, error: errorMsg });
        });
    });
}
exports.VCCService = VCCService;
